#include <QMessageBox>

#include "MainWindow.h"

Dictate1 *dictate1; // Must be global so that TimeLimiter can access those and call makeGrey()
Dictate2 *dictate2;

MainWindow::MainWindow() : QWidget() {
   setWindowTitle("Diktat til trinindplacering");
   nCurrentPage=0;

   brBackground.setColor(QColor(0x15,0x15,0x55,255));
   brBackground.setStyle(Qt::SolidPattern);
   palette.setBrush(QPalette::Window,brBackground);
   setPalette(palette);

   overview=new Overview(this);
   welcome=new Welcome(this);
   info=new Info(this);
   info->hide(); // If not hidden to begin with, the windows show up at mysterious places!
   help1=new Dictate1Help(this);
   help1->hide();
   dictate1=new Dictate1(this);
   dictate1->hide();
   help2=new Dictate2Help(this);
   help2->hide();
   dictate2=new Dictate2(this);
   dictate2->hide();
   results=new Results(this);
   results->hide();

   scr=new QScrollArea;
   scr->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
   scr->setWidget(dictate2);
   scr->setMinimumSize(QSize(850,0)); // Critical, and a pain in the ass!
   scr->setFrameStyle(0); // Removes the annoying tab/selection flash around the scroll area

   right_margin=new DarkMargin(this);

   layout=new QHBoxLayout;
   layout->setMargin(0); // Rewmoves the space around the entire layout
   layout->setSpacing(0); // Removes the space between the three frames
   layout->addWidget(overview,1);
   layout->addWidget(welcome,4,Qt::AlignHCenter);
   layout->addWidget(right_margin,1);
   setLayout(layout);

   connect(welcome,SIGNAL(nextPage()),this,SLOT(nextPage()));
   connect(info,SIGNAL(nextPage()),this,SLOT(nextPage()));
   connect(help1,SIGNAL(nextPage()),this,SLOT(nextPage()));
   connect(dictate1,SIGNAL(nextPage()),this,SLOT(nextPage()));
   connect(help2,SIGNAL(nextPage()),this,SLOT(nextPage()));
   connect(dictate2,SIGNAL(nextPage()),this,SLOT(nextPage()));
}

void MainWindow::nextPage() {
   overview->nextPage();
   switch (nCurrentPage) {
      case 0:
         welcome->hide();
         layout->removeWidget(welcome);
         layout->insertWidget(1,info,4,Qt::AlignHCenter);
         info->show();
         break;
      case 1:
         info->hide();
         layout->removeWidget(info);
         layout->insertWidget(1,help1,4,Qt::AlignHCenter);
         help1->show();
         break;
      case 2:
         help1->hide();
         layout->removeWidget(help1);
         layout->insertWidget(1,dictate1,4,Qt::AlignHCenter);
         dictate1->show();
         break;
      case 3:
         dictate1->hide();
         layout->removeWidget(dictate1);
         if (dictate1->isPassed()) {
            layout->insertWidget(1,help2,4,Qt::AlignHCenter);
            help2->show();
         }
         else {
            overview->nextPage();
            overview->nextPage();
            layout->insertWidget(1,results,4);
            results->loadResults();
            results->show();
            QMessageBox::information(this,tr("Vigtigt!"),tr("Du skal huske at udskrive resultaterne.\nFå evt. din lærer til at hjælpe."),QMessageBox::Ok);
         }
         break;
      case 4:
         help2->hide();
         layout->removeWidget(help2);
         layout->insertWidget(1,scr,4,Qt::AlignHCenter);
         scr->show(); // Apparently not really needed(!?)
         break;
      case 5:
         scr->hide();
         layout->removeWidget(scr);
         layout->insertWidget(1,results,4);
         results->loadResults();
         results->show();
         QMessageBox::information(this,tr("Vigtigt!"),tr("Du skal huske at udskrive resultaterne.\nFå evt. din lærer til at hjælpe."),QMessageBox::Ok);
         break;
   }
   nCurrentPage++;
}
